@@ -2,27 +2,10 @@ from __future__ import absolute_import, unicode_literals
 import sys
 import functools
 import json
-from . import base
 
+import click
 
-# TODO rewrite some of this to be not terrible
-def is_colored(fn):
-    prefix, suffix = {
-                '_red': ('\033[91m', '\033[0m'),
-                '_yellow': ('\033[93m', '\033[0m'),
-                '_green': ('\033[92m', '\033[0m'),
-                '_white': ('', ''),
-                '_blue': ('\033[94m', '\033[0m'),
-                '_open_group': ('\033[94m', '\033[0m'),
-    }.get(fn.__name__, ('', ''))
-
-    @functools.wraps(fn)
-    def wrapper(self, text):
-        if self.color:
-            return prefix + fn(self, text) + suffix
-        else:
-            return fn(self, text)
-    return wrapper
+from polyswarm.formatters import base
 
 
 def is_grouped(fn):
@@ -52,7 +35,7 @@ class TextOutput(base.BaseOutput):
 
     def _output(self, output, write):
         if write:
-            self.out.write('\n'.join(output) + '\n\n')
+            click.echo('\n'.join(output) + '\n', file=self.out)
         else:
             return output
 
@@ -119,6 +102,8 @@ class TextOutput(base.BaseOutput):
             output.append(self._red('Status: Failed'))
         elif instance.window_closed:
             output.append(self._white('Status: Assertion window closed'))
+        elif instance.community == 'stream':
+            output.append(self._white('Status: This artifact has not been scanned. You can trigger a scan now.'))
         elif timeout:
             output.append(self._yellow('Status: Lookup timed-out, please retry'))
         else:
@@ -198,6 +183,23 @@ class TextOutput(base.BaseOutput):
                                   .format(artifact.artifact_name, artifact.name)))
         return self._output(output, write)
 
+    def _dfs_mapping_render(self, output, path, tree, depth=0):
+        tree_string = (' | ' * (depth - 1)) + ' +-' if depth > 0 else ''
+        current_path = '.'.join(path)
+        if not tree:
+            output.append(self._white(tree_string + current_path))
+        else:
+            if path:
+                output.append(self._white(tree_string + current_path))
+            for k, v in tree.items():
+                self._dfs_mapping_render(output, path + [k], v, depth=depth + 1)
+
+    def mapping(self, mapping, write=True):
+        output = []
+        output.append(self._white('============================= Mapping ============================='))
+        self._dfs_mapping_render(output, [], mapping.json)
+        return self._output(output, write)
+
     def metadata(self, instance, write=True):
         output = []
         output.append(self._white('============================= Metadata ============================='))
@@ -262,31 +264,25 @@ class TextOutput(base.BaseOutput):
 
         return self._output(output, write)
 
-
-    @is_colored
     @is_grouped
     def _white(self, text):
-        return '%s' % text
+        return click.style(text, fg='white')
 
-    @is_colored
     @is_grouped
     def _yellow(self, text):
-        return '%s' % text
+        return click.style(text, fg='yellow')
 
-    @is_colored
     @is_grouped
     def _red(self, text):
-        return '%s' % text
+        return click.style(text, fg='red')
 
-    @is_colored
     @is_grouped
     def _blue(self, text):
-        return '%s' % text
+        return click.style(text, fg='blue')
 
-    @is_colored
     @is_grouped
     def _green(self, text):
-        return '%s' % text
+        return click.style(text, fg='green')
 
     def _open_group(self):
         self._depth += 1
